@@ -13,6 +13,7 @@ namespace Composer\Pcre\PregTests;
 
 use Composer\Pcre\BaseTestCase;
 use Composer\Pcre\Preg;
+use Composer\Pcre\UnexpectedNullMatchException;
 
 class ReplaceCallbackTest extends BaseTestCase
 {
@@ -31,6 +32,16 @@ class ReplaceCallbackTest extends BaseTestCase
         self::assertSame('abc(d)', $result);
     }
 
+    public function testSuccessWithOffset(): void
+    {
+        $result = Preg::replaceCallback('{(?P<m>d)}', function ($match) {
+            return '('.$match[0][0].')';
+        }, 'abcd', -1, $count, PREG_OFFSET_CAPTURE);
+
+        self::assertSame(1, $count);
+        self::assertSame('abc(d)', $result);
+    }
+
     public function testSuccessNoRef(): void
     {
         $result = Preg::replaceCallback('{(?P<m>d)}', function ($match) {
@@ -50,6 +61,26 @@ class ReplaceCallbackTest extends BaseTestCase
         self::assertSame('def', $result);
     }
 
+    public function testSuccessStrictGroups(): void
+    {
+        $result = Preg::replaceCallbackStrictGroups('{(?P<m>\d)(?<matched>a)?}', function ($match) {
+            return strtoupper($match['matched']);
+        }, '3a', -1, $count);
+
+        self::assertSame(1, $count);
+        self::assertSame('A', $result);
+    }
+
+    public function testFailStrictGroups(): void
+    {
+        self::expectException(UnexpectedNullMatchException::class);
+        self::expectExceptionMessage('Pattern "{(?P<m>\d)(?<unmatched>a)?}" had an unexpected unmatched group "unmatched", make sure the pattern always matches or use replaceCallback() instead.');
+
+        $result = Preg::replaceCallbackStrictGroups('{(?P<m>\d)(?<unmatched>a)?}', function ($match) {
+            return strtoupper($match['unmatched']);
+        }, '123', -1, $count);
+    }
+
     public function testBadPatternThrowsIfWarningsAreNotThrowing(): void
     {
         $this->expectPcreException($pattern = '{(?P<m>d)');
