@@ -13,6 +13,7 @@ namespace Composer\Pcre\RegexTests;
 
 use Composer\Pcre\BaseTestCase;
 use Composer\Pcre\Regex;
+use Composer\Pcre\UnexpectedNullMatchException;
 
 class MatchTest extends BaseTestCase
 {
@@ -37,6 +38,19 @@ class MatchTest extends BaseTestCase
         self::assertSame(array(), $result->matches);
     }
 
+    public function testSuccessStrictGroups(): void
+    {
+        $result = Regex::matchStrictGroups('{(?P<m>\d)(?<matched>a)?}', '3a');
+        self::assertSame(array(0 => '3a', 'm' => '3', 1 => '3', 'matched' => 'a', 2 => 'a'), $result->matches);
+    }
+
+    public function testFailStrictGroups(): void
+    {
+        self::expectException(UnexpectedNullMatchException::class);
+        self::expectExceptionMessage('Pattern "{(?P<m>\d)(?<unmatched>b)?}" had an unexpected unmatched group "unmatched", make sure the pattern always matches or use match() instead.');
+        Regex::matchStrictGroups('{(?P<m>\d)(?<unmatched>b)?}', '123');
+    }
+
     public function testBadPatternThrowsIfWarningsAreNotThrowing(): void
     {
         $this->expectPcreException($pattern = '{abc');
